"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const devkit_1 = require("@nrwl/devkit");
const utils_1 = require("../../utils");
const poetry_1 = require("../../poetry");
function runExecutor(options, context) {
    return tslib_1.__asyncGenerator(this, arguments, function* runExecutor_1() {
        console.log('Executor ran for DevServer', options);
        const projectRoot = utils_1.getProjectRoot(context);
        const { host, port, migrate } = options;
        const baseUrl = `http://${host}:${port}`;
        try {
            const checkStatus = (data) => {
                if (data.includes('Application startup complete.')) {
                    return poetry_1.CmdStatus.Done;
                }
                else if (data.includes('ERROR:')) {
                    return poetry_1.CmdStatus.Error;
                }
                return poetry_1.CmdStatus.Continue;
            };
            if (migrate) {
                const dbMigrate = poetry_1.executePoetryCommand(devkit_1.joinPathFragments(projectRoot, 'src'), 'run', 'alembic', 'upgrade', 'head');
                if (!dbMigrate) {
                    return yield tslib_1.__await({ success: false });
                }
            }
            const child = yield tslib_1.__await(poetry_1.runPoetryCommandAsync(devkit_1.joinPathFragments(projectRoot, 'src'), [
                'run',
                'uvicorn',
                'main:app',
                '--reload',
                '--port',
                port.toString(),
                '--host',
                host,
            ], checkStatus));
            if (!child) {
                return yield tslib_1.__await({ success: false });
            }
            yield yield tslib_1.__await({
                success: true,
                baseUrl,
            });
            return yield tslib_1.__await(poetry_1.waitForCommand(child));
        }
        catch (e) {
            console.error('Executor failed: ', e);
            return yield tslib_1.__await({ success: false });
        }
    });
}
exports.default = runExecutor;
//# sourceMappingURL=executor.js.map