"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const devkit_1 = require("@nrwl/devkit");
const run_tasks_in_serial_1 = require("@nrwl/workspace/src/utilities/run-tasks-in-serial");
const path = require("path");
const poetry_1 = require("../../poetry");
const defaults_1 = require("../../defaults");
function normalizeOptions(host, options) {
    var _a, _b, _c;
    const name = devkit_1.names(options.name).fileName;
    const projectDirectory = options.directory
        ? devkit_1.names(options.directory).fileName
        : name;
    const projectName = projectDirectory.replace(new RegExp('/', 'g'), '-');
    const projectTitle = (_a = options.title) !== null && _a !== void 0 ? _a : projectName;
    const projectRoot = devkit_1.joinPathFragments(devkit_1.getWorkspaceLayout(host).appsDir, projectDirectory);
    const parsedTags = options.tags
        ? options.tags.split(',').map((s) => s.trim())
        : [];
    return Object.assign(Object.assign({}, options), { projectName,
        projectTitle,
        projectRoot,
        projectDirectory,
        parsedTags, pgUser: (_b = options.pgUser) !== null && _b !== void 0 ? _b : '', pgDb: (_c = options.pgDb) !== null && _c !== void 0 ? _c : '', pgPassword: options.pgPassword });
}
function addFiles(host, options) {
    const templateOptions = Object.assign(Object.assign(Object.assign({}, options), devkit_1.names(options.name)), { offsetFromRoot: devkit_1.offsetFromRoot(options.projectRoot), 
        // Hack for copying dotfiles - use as a template in the filename
        // e.g. "__dot__eslintrc.js" => ".eslintrc.js"
        dot: '.', template: '' });
    devkit_1.generateFiles(host, path.join(__dirname, 'files'), options.projectRoot, templateOptions);
}
function updateExtensionRecommendations(host) {
    if (!host.exists(defaults_1.VSCodeExtensionsFilePath)) {
        host.write(defaults_1.VSCodeExtensionsFilePath, '{ "recommendations": [] }');
    }
    devkit_1.updateJson(host, defaults_1.VSCodeExtensionsFilePath, (json) => {
        var _a;
        (_a = json.recommendations) !== null && _a !== void 0 ? _a : (json.recommendations = []);
        for (const extension of defaults_1.recommendedExtensions) {
            if (Array.isArray(json.recommendations) &&
                !json.recommendations.includes(extension))
                json.recommendations.push(extension);
        }
        return json;
    });
}
function default_1(host, options) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const normalizedOptions = normalizeOptions(host, options);
        const { projectRoot } = normalizedOptions;
        devkit_1.addProjectConfiguration(host, normalizedOptions.projectName, {
            root: projectRoot,
            projectType: 'application',
            sourceRoot: devkit_1.joinPathFragments(projectRoot, 'src'),
            targets: {
                serve: {
                    executor: 'nx-python-fastapi:serve',
                },
                test: {
                    executor: 'nx-python-fastapi:test',
                    outputs: [devkit_1.joinPathFragments('coverage', projectRoot)],
                },
                lint: {
                    executor: 'nx-python-fastapi:lint',
                },
                format: {
                    executor: 'nx-python-fastapi:format',
                },
            },
            tags: normalizedOptions.parsedTags,
        });
        addFiles(host, normalizedOptions);
        updateExtensionRecommendations(host);
        const poetryInstall = poetry_1.runPoetryCommand(projectRoot, 'install');
        const format = poetry_1.runPoetryCommand(projectRoot, 'run', 'black', 'src');
        const preStart = options.pgDb
            ? poetry_1.runPoetryCommand(devkit_1.joinPathFragments(projectRoot, 'src'), 'run', 'python', 'pre_start.py')
            : () => {
                console.log('No database name, skipping initialization. Run "poetry run python pre_start.py" from the src directory');
            };
        return run_tasks_in_serial_1.runTasksInSerial(poetryInstall, format, preStart);
    });
}
exports.default = default_1;
//# sourceMappingURL=generator.js.map